dawgdad documentation
=====================

**dawgdad** is a Python library for data scientists, machine learning engineers, and statisticians. It contains statistical and graphical functions for making sense of data to create information and understanding.

- Supervised machine learning
- Six Sigma methodology
- Regular expressions
- Process capability
- Process variation
- Excel file edits
- Taguchi Methods
- Data Science
- Automation
- Analytics

Why **dawgdad**?

- Equivalent Python functions that are available in R, SAS, JMP, Minitab
- Other packages have limited process control analysis features
- Other packages are abandoned or inadequately supported
- Functions to support measurement system analysis
- Functions to simplify statistics, graphs, etc.
- Functions to support process control charts
- Functions to support SQL functionality
- Develop a free open source package

.. This is how you insert a comment; the next line is for a cross-reference (if you delete dot dot space)

.. Check out the :doc:`rst_document_name` section for further information.


.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Contents:

   install.rst
   update.rst
   scripts.rst
   contributing.rst
   dawgdad.rst

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Scripts:

   xmr_control_charts.rst
   xbarr_control_charts.rst
   cubic_spline_y_x_line_plot.rst
   exponentially_weighted_moving_average_y_x_line_plot.rst
   piecewise_natural_cubic_spline.rst
   y1_y2_x_line_charts_separate_y_axes.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
